#!/bin/bash

###############################################################################
# Definitions
###############################################################################

PASSWD_SCP="scp:x:1007:104:SCP user:/.:/bin/bash"
PASSWD_DEF="defaults:x:1008:104::/opt/./:/usr/bin/cli"
SHADOW_SCP="#" #"scp:\$1\$q6lQg5m6\$cdr44mscZ2A5JzqAu23w90:14132:0:99999:7:::"
SHADOW_DEF="defaults:\$1\$5MwaT/54\$kJM8IVnM89kC3C0.TL4mY.:15631:0:99999:7:::"

###############################################################################
# FUNCTIONS
###############################################################################

###############################################################################
# The order of the first 9 lines of the passwd and shadow files is static
# because Spectracom software depends on it.
# Upgrade to Release 3.6.0 or greater
# $1 - filename
###############################################################################
function ReplaceSCPandAddDefaults
{
    # Delete temp files
    rm -f /tmp/$1.tmp
    
    # Test for defaults
    cat /etc/$1 | grep "defaults:"

    # grep return 0 when it finds defaults indicating we must stop
    if [ $? == 0 ]
    then
        return 0
    fi

    # Modify scp line and add defaults
    while read line
    do
        # Look for scp line
        if [ "${line:0:4}" == "scp:" ]
        then
            if [ "$1" == "passwd" ]
            then
                echo $PASSWD_SCP >> /tmp/$1.tmp
                echo $PASSWD_DEF >> /tmp/$1.tmp
            else
                echo $line       >> /tmp/$1.tmp
                echo $SHADOW_DEF >> /tmp/$1.tmp
            fi
        else
            echo $line >> /tmp/$1.tmp
        fi

    done < /etc/$1

    sync  
    mv /tmp/$1.tmp /etc/$1
    chmod 664 /etc/$1

    return 0
}

###############################################################################
# MAIN
###############################################################################

# Update /etc/passwd
ReplaceSCPandAddDefaults passwd

# Update /etc/shadow
ReplaceSCPandAddDefaults shadow

# Move the upgrade kernel and ram disk to /boot
mv /opt/upgrade/temp/upkernel /opt/upgrade/temp/uprd.img.gz /boot

# Change owner and group to root
chown root:root /boot/upkernel /boot/uprd.img.gz

# Write a new menu.lst file to boot upgrade kernel with ram disk
echo "
default=0
timeout=1
color green/black light-green/black
title Vile Linux 2.5 Upgrade
    kernel --no-mem-option /boot/upkernel
    initrd /boot/uprd.img.gz
title Vile Linux  (Failover Image)
    root (hd0,0)
    kernel --no-mem-option /boot/kernel root=/dev/hda1
" > /boot/grub/menu.lst

# Flush all file system buffers and reboot
sync
shutdown -t1 -a -r -n now

###############################################################################
# END
###############################################################################
